function LPSignal = lowpass (Signal, FCutoff, NOrder)
%
%  FUNCTION LOWPASS (SIGNAL, FCUTOFF, NORDER)
%
%  DESCRIPTION
%    Lowpass filtering of time sequence.
% 
%  PARAMETERS
%    Signal  - Time sequence
%    FCutoff - Cutoff frequency (relative to Nyquist freq.)
%    NOrder  - Order of filter
%
%  ... Drs. P. ..
%
if nargin<3 
   NOrder=100; 
end

f = [0.0 FCutoff FCutoff 1.0];
m = [1.0 1.0 0.0 0.0];
b = fir2(NOrder,f,m);

LPSignal = filtfilt (b, 1, Signal);


